function myResult = IOErrTest(fName)
%IOErrTest Demonstrates file I/O, MExeptions and try-catch blocks.
% IOErrTest reads two floating point values separated by a space from a
% file and divides the first by the second. Any exceptions occuring are
% caught. Exceptions are caught and displayed but not "handled."
%
% Preconditions - Input file (fName) exists and contains two values.
%
% Argument - A string containing the file name.
%
% Returns - Two double values in a column vector.
%
% Postconditions - File remains unchanged.
%
% Created by Dr. C. S. Tritt
% Created and last revised: 11/27/11

   try
      % Open file, read data & close file.
      fid = fopen(fName, 'r');
      fData = fscanf(fid, '%f %f');
      fclose(fid);
      
      % Do math and test result.
      myResult = fData(1)/fData(2);
      if myResult == Inf
         anException = MException('MY_ERROR:ProbableDivideByZero', ...
            'a/b where a is %f and b is %f', fData(1), fData(2));
         throw(anException);
      end

   catch myException % This will catch all exceptions.
      fprintf('Exception content:\n\n')
      disp(myException)
      fprintf('Exception stack:\n\n')
      disp(myException.stack)
   end
end